---
name: Bug Report
about: Create a bug report to help us improve CellRank
title: "[FEATURE NAME]"
labels: bug
assignees: "michalk8"
---

<!-- Please give a clear and concise description of the bug: -->
...

<!-- Put a minimal reproducible example in the block below: -->
```python
...
```

<!-- Put your error output in the block below (if applicable, else delete the block): -->
```pytb
...
```

#### Versions:
<!-- Output of cellrank.logging.print_versions() -->
> ...
